/*                     __                                               *\
**     ________ ___   / /  ___     Scala API                            **
**    / __/ __// _ | / /  / _ |    (c) 2003-2006, LAMP/EPFL             **
**  __\ \/ /__/ __ |/ /__/ __ |                                         **
** /____/\___/_/ |_/____/_/ | |                                         **
**                          |/                                          **
\*                                                                      */

// $Id: MalformedAttributeException.scala 8744 2006-09-22 09:38:30Z michelou $


package scala.xml


case class MalformedAttributeException(msg: String) extends java.lang.RuntimeException(msg)
